@@ -2,6 +2,7 @@
 
 from contextlib import contextmanager
 import logging
+import os
 import math
 from pathlib import Path
 import warnings
@@ -9,52 +10,81 @@ import warnings
 import numpy as np
 
 import rasterio
+from rasterio.coords import disjoint_bounds
 from rasterio.enums import Resampling
+from rasterio.errors import RasterioDeprecationWarning
 from rasterio import windows
 from rasterio.transform import Affine
 
-
 logger = logging.getLogger(__name__)
 
 
 def copy_first(merged_data, new_data, merged_mask, new_mask, **kwargs):
+    """Returns the first available pixel."""
     mask = np.empty_like(merged_mask, dtype="bool")
     np.logical_not(new_mask, out=mask)
     np.logical_and(merged_mask, mask, out=mask)
-    np.copyto(merged_data, new_data, where=mask)
+    np.copyto(merged_data, new_data, where=mask, casting="unsafe")
 
 
 def copy_last(merged_data, new_data, merged_mask, new_mask, **kwargs):
+    """Returns the last available pixel."""
     mask = np.empty_like(merged_mask, dtype="bool")
     np.logical_not(new_mask, out=mask)
-    np.copyto(merged_data, new_data, where=mask)
+    np.copyto(merged_data, new_data, where=mask, casting="unsafe")
 
 
 def copy_min(merged_data, new_data, merged_mask, new_mask, **kwargs):
+    """Returns the minimum value pixel."""
     mask = np.empty_like(merged_mask, dtype="bool")
     np.logical_or(merged_mask, new_mask, out=mask)
     np.logical_not(mask, out=mask)
-    np.minimum(merged_data, new_data, out=merged_data, where=mask)
+    np.minimum(merged_data, new_data, out=merged_data, where=mask, casting="unsafe")
     np.logical_not(new_mask, out=mask)
     np.logical_and(merged_mask, mask, out=mask)
-    np.copyto(merged_data, new_data, where=mask)
+    np.copyto(merged_data, new_data, where=mask, casting="unsafe")
 
 
 def copy_max(merged_data, new_data, merged_mask, new_mask, **kwargs):
+    """Returns the maximum value pixel."""
     mask = np.empty_like(merged_mask, dtype="bool")
     np.logical_or(merged_mask, new_mask, out=mask)
     np.logical_not(mask, out=mask)
-    np.maximum(merged_data, new_data, out=merged_data, where=mask)
+    np.maximum(merged_data, new_data, out=merged_data, where=mask, casting="unsafe")
     np.logical_not(new_mask, out=mask)
     np.logical_and(merged_mask, mask, out=mask)
-    np.copyto(merged_data, new_data, where=mask)
+    np.copyto(merged_data, new_data, where=mask, casting="unsafe")
+
+
+def copy_sum(merged_data, new_data, merged_mask, new_mask, **kwargs):
+    """Returns the sum of all pixel values."""
+    mask = np.empty_like(merged_mask, dtype="bool")
+    np.logical_or(merged_mask, new_mask, out=mask)
+    np.logical_not(mask, out=mask)
+    np.add(merged_data, new_data, out=merged_data, where=mask, casting="unsafe")
+    np.logical_not(new_mask, out=mask)
+    np.logical_and(merged_mask, mask, out=mask)
+    np.copyto(merged_data, new_data, where=mask, casting="unsafe")
+
+
+def copy_count(merged_data, new_data, merged_mask, new_mask, **kwargs):
+    """Returns the count of valid pixels."""
+    mask = np.empty_like(merged_mask, dtype="bool")
+    np.logical_or(merged_mask, new_mask, out=mask)
+    np.logical_not(mask, out=mask)
+    np.add(merged_data, mask, out=merged_data, where=mask, casting="unsafe")
+    np.logical_not(new_mask, out=mask)
+    np.logical_and(merged_mask, mask, out=mask)
+    np.copyto(merged_data, mask, where=mask, casting="unsafe")
 
 
 MERGE_METHODS = {
-    'first': copy_first,
-    'last': copy_last,
-    'min': copy_min,
-    'max': copy_max
+    "first": copy_first,
+    "last": copy_last,
+    "min": copy_min,
+    "max": copy_max,
+    "sum": copy_sum,
+    "count": copy_count,
 }
 
 
@@ -69,6 +99,7 @@ def merge(
     output_count=None,
     resampling=Resampling.nearest,
     method="first",
+    target_aligned_pixels=False,
     dst_path=None,
     dst_kwds=None,
 ):
@@ -87,7 +118,7 @@ def merge(
 
     Parameters
     ----------
-    datasets : list of dataset objects opened in 'r' mode, filenames or pathlib.Path objects
+    datasets : list of dataset objects opened in 'r' mode, filenames or PathLike objects
         source datasets to be merged.
     bounds: tuple, optional
         Bounds of the output image (left, bottom, right, top).
@@ -102,8 +133,9 @@ def merge(
     dtype: numpy dtype or string
         dtype to use in outputfile. If not set, uses the dtype value in the
         first input raster.
-    precision: float, optional
-        Number of decimal points of precision when computing inverse transform.
+    precision: int, optional
+        This parameters is unused, deprecated in rasterio 1.3.0, and
+        will be removed in version 2.0.0.
     indexes : list of ints or a single int, optional
         bands to read and merge
     output_count: int, optional
@@ -119,11 +151,6 @@ def merge(
             min: pixel-wise min of existing and new
             max: pixel-wise max of existing and new
         or custom callable with signature:
-
-        def function(merged_data, new_data, merged_mask, new_mask, index=None, roff=None, coff=None):
-
-            Parameters
-            ----------
             merged_data : array_like
                 array to update with new_data
             new_data : array_like
@@ -139,7 +166,11 @@ def merge(
             coff: int
                 column offset in base array
 
-    dst_path : str or Pathlike, optional
+    target_aligned_pixels : bool, optional
+        Whether to adjust output image bounds so that pixel coordinates
+        are integer multiples of pixel size, matching the ``-tap``
+        options of GDAL utilities.  Default: False.
+    dst_path : str or PathLike, optional
         Path of output dataset
     dst_kwds : dict, optional
         Dictionary of creation options and other paramters that will be
@@ -159,6 +190,12 @@ def merge(
                 coordinate system
 
     """
+    if precision is not None:
+        warnings.warn(
+            "The precision parameter is unused, deprecated, and will be removed in 2.0.0.",
+            RasterioDeprecationWarning,
+        )
+
     if method in MERGE_METHODS:
         copyto = MERGE_METHODS[method]
     elif callable(method):
@@ -168,7 +205,7 @@ def merge(
                          .format(method, list(MERGE_METHODS.keys())))
 
     # Create a dataset_opener object to use in several places in this function.
-    if isinstance(datasets[0], str) or isinstance(datasets[0], Path):
+    if isinstance(datasets[0], (str, os.PathLike)):
         dataset_opener = rasterio.open
     else:
 
@@ -216,10 +253,6 @@ def merge(
             ys.extend([bottom, top])
         dst_w, dst_s, dst_e, dst_n = min(xs), min(ys), max(xs), max(ys)
 
-    logger.debug("Output bounds: %r", (dst_w, dst_s, dst_e, dst_n))
-    output_transform = Affine.translation(dst_w, dst_n)
-    logger.debug("Output transform, before scaling: %r", output_transform)
-
     # Resolution/pixel size
     if not res:
         res = first_res
@@ -227,18 +260,19 @@ def merge(
         res = (res, res)
     elif len(res) == 1:
         res = (res[0], res[0])
-    output_transform *= Affine.scale(res[0], -res[1])
-    logger.debug("Output transform, after scaling: %r", output_transform)
+
+    if target_aligned_pixels:
+        dst_w = math.floor(dst_w / res[0]) * res[0]
+        dst_e = math.ceil(dst_e / res[0]) * res[0]
+        dst_s = math.floor(dst_s / res[1]) * res[1]
+        dst_n = math.ceil(dst_n / res[1]) * res[1]
 
     # Compute output array shape. We guarantee it will cover the output
     # bounds completely
-    output_width = int(math.ceil((dst_e - dst_w) / res[0]))
-    output_height = int(math.ceil((dst_n - dst_s) / res[1]))
+    output_width = int(round((dst_e - dst_w) / res[0]))
+    output_height = int(round((dst_n - dst_s) / res[1]))
 
-    # Adjust bounds to fit
-    dst_e, dst_s = output_transform * (output_width, output_height)
-    logger.debug("Output width: %d, height: %d", output_width, output_height)
-    logger.debug("Adjusted bounds: %r", (dst_w, dst_s, dst_e, dst_n))
+    output_transform = Affine.translation(dst_w, dst_n) * Affine.scale(res[0], -res[1])
 
     if dtype is not None:
         dt = dtype
@@ -251,6 +285,7 @@ def merge(
     out_profile["height"] = output_height
     out_profile["width"] = output_width
     out_profile["count"] = output_count
+    out_profile["dtype"] = dt
     if nodata is not None:
         out_profile["nodata"] = nodata
 
@@ -290,6 +325,10 @@ def merge(
             # This approach uses the maximum amount of memory to solve the
             # problem. Making it more efficient is a TODO.
 
+            if disjoint_bounds((dst_w, dst_s, dst_e, dst_n), src.bounds):
+                logger.debug("Skipping source: src=%r, window=%r", src)
+                continue
+
             # 1. Compute spatial intersection of destination and source
             src_w, src_s, src_e, src_n = src.bounds
 
@@ -299,24 +338,27 @@ def merge(
             int_n = src_n if src_n < dst_n else dst_n
 
             # 2. Compute the source window
-            src_window = windows.from_bounds(
-                int_w, int_s, int_e, int_n, src.transform, precision=precision
-            )
-            logger.debug("Src %s window: %r", src.name, src_window)
+            src_window = windows.from_bounds(int_w, int_s, int_e, int_n, src.transform)
 
             # 3. Compute the destination window
             dst_window = windows.from_bounds(
-                int_w, int_s, int_e, int_n, output_transform, precision=precision
+                int_w, int_s, int_e, int_n, output_transform
             )
 
             # 4. Read data in source window into temp
-            src_window = src_window.round_shape(pixel_precision=0)
-            dst_window = dst_window.round_shape(pixel_precision=0)
-            trows, tcols = dst_window.height, dst_window.width
-            temp_shape = (src_count, trows, tcols)
-            temp = src.read(
+            src_window_rnd_shp = src_window.round_lengths()
+            dst_window_rnd_shp = dst_window.round_lengths()
+            dst_window_rnd_off = dst_window_rnd_shp.round_offsets()
+
+            temp_height, temp_width = (
+                dst_window_rnd_off.height,
+                dst_window_rnd_off.width,
+            )
+            temp_shape = (src_count, temp_height, temp_width)
+
+            temp_src = src.read(
                 out_shape=temp_shape,
-                window=src_window,
+                window=src_window_rnd_shp,
                 boundless=False,
                 masked=True,
                 indexes=indexes,
@@ -324,9 +366,11 @@ def merge(
             )
 
         # 5. Copy elements of temp into dest
-        dst_window = dst_window.round_offsets(pixel_precision=0)
-        roff, coff = dst_window.row_off, dst_window.col_off
-        region = dest[:, roff:roff + trows, coff:coff + tcols]
+        roff, coff = (
+            max(0, dst_window_rnd_off.row_off),
+            max(0, dst_window_rnd_off.col_off),
+        )
+        region = dest[:, roff : roff + temp_height, coff : coff + temp_width]
 
         if math.isnan(nodataval):
             region_mask = np.isnan(region)
@@ -335,8 +379,9 @@ def merge(
         else:
             region_mask = region == nodataval
 
+        # Ensure common shape, resolving issue #2202.
+        temp = temp_src[:, : region.shape[1], : region.shape[2]]
         temp_mask = np.ma.getmask(temp)
-
         copyto(region, temp, region_mask, temp_mask, index=idx, roff=roff, coff=coff)
 
     if dst_path is None:
