@@ -4,15 +4,16 @@ import os
 import click
 from cligj import (
     precision_opt, indent_opt, compact_opt, projection_geographic_opt,
-    projection_mercator_opt, projection_projected_opt, sequence_opt,
+    projection_mercator_opt, projection_projected_opt,
     use_rs_opt, geojson_type_feature_opt, geojson_type_bbox_opt,
     geojson_type_collection_opt)
 
 from .helpers import write_features, to_lower
-import rasterio
+from rasterio.rio import options
 from rasterio.warp import transform_bounds
 
-logger = logging.getLogger('rio')
+
+logger = logging.getLogger(__name__)
 
 
 # Bounds command.
@@ -29,14 +30,23 @@ logger = logging.getLogger('rio')
 @click.option(
     '--dst-crs', default='', metavar="EPSG:NNNN", callback=to_lower,
     help="Output in specified coordinates.")
-@sequence_opt
+@options.sequence_opt
 @use_rs_opt
-@geojson_type_collection_opt(True)
-@geojson_type_feature_opt(False)
+@geojson_type_feature_opt(True)
 @geojson_type_bbox_opt(False)
 @click.pass_context
-def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
-           sequence, use_rs, geojson_type):
+def bounds(
+    ctx,
+    input,
+    precision,
+    indent,
+    compact,
+    projection,
+    dst_crs,
+    sequence,
+    use_rs,
+    geojson_type,
+):
     """Write bounding boxes to stdout as GeoJSON for use with, e.g.,
     geojsonio
 
@@ -46,8 +56,6 @@ def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
     the projection parameter.
     """
     import rasterio.warp
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-    logger = logging.getLogger('rio')
     dump_kwds = {'sort_keys': True}
     if indent:
         dump_kwds['indent'] = indent
@@ -56,7 +64,7 @@ def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
     stdout = click.get_text_stream('stdout')
 
     # This is the generator for (feature, bbox) pairs.
-    class Collection(object):
+    class Collection:
 
         def __init__(self, env):
             self._xs = []
@@ -105,13 +113,12 @@ def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
                 self._xs.extend(bbox[::2])
                 self._ys.extend(bbox[1::2])
 
-    try:
-        with rasterio.Env(CPL_DEBUG=verbosity > 2) as env:
-            write_features(
-                stdout, Collection(env), sequence=sequence,
-                geojson_type=geojson_type, use_rs=use_rs,
-                **dump_kwds)
-
-    except Exception:
-        logger.exception("Exception caught during processing")
-        raise click.Abort()
+    with ctx.obj["env"] as env:
+        write_features(
+            stdout,
+            Collection(env),
+            sequence=sequence,
+            geojson_type=geojson_type,
+            use_rs=use_rs,
+            **dump_kwds
+        )
