@@ -1,6 +1,5 @@
 """``pytest`` fixtures."""
 
-
 import functools
 import operator
 import os
@@ -11,15 +10,17 @@ import zipfile
 
 import affine
 import boto3
-from click.testing import CliRunner
-import pytest
 import numpy as np
+import pytest
+from click.testing import CliRunner
 
 import rasterio
+import rasterio.env
+from rasterio.coords import BoundingBox
 from rasterio.crs import CRS
 from rasterio.enums import ColorInterp
 from rasterio.env import GDALVersion
-
+from affine import Affine
 
 DEFAULT_SHAPE = (10, 10)
 
@@ -379,10 +380,6 @@ def basic_image_file(tmpdir, basic_image):
     string
         Filename of test raster file
     """
-
-    from affine import Affine
-    import rasterio
-
     image = basic_image
 
     outfilename = str(tmpdir.join('basic_image.tif'))
@@ -414,10 +411,6 @@ def pixelated_image_file(tmpdir, pixelated_image):
     string
         Filename of test raster file
     """
-
-    from affine import Affine
-    import rasterio
-
     image = pixelated_image
 
     outfilename = str(tmpdir.join('pixelated_image.tif'))
@@ -449,10 +442,6 @@ def rotated_image_file(tmpdir, pixelated_image):
     string
         Filename of test raster file
     """
-
-    from affine import Affine
-    import rasterio
-
     image = 128 * np.ones((1000, 2000), dtype=np.uint8)
 
     rotated_transform = Affine(-0.05, 0.07, 481060,
@@ -476,10 +465,42 @@ def rotated_image_file(tmpdir, pixelated_image):
     return outfilename
 
 
+@pytest.fixture()
+def image_file_with_custom_size_and_transform(tmpdir):
+    """
+    A basic raster file with a 10x10 array containing a
+    caller supplied transform.
+
+    Returns
+    -------
+
+    string
+        Filename of test raster file
+    """
+    def inner(width, height, transform):
+        image = np.zeros((height, width))
+
+        outfilename = str(tmpdir.join('basic_image.tif'))
+        kwargs = {
+            "crs": CRS({'init': 'epsg:4326'}),
+            "transform": transform,
+            "count": 1,
+            "dtype": rasterio.uint8,
+            "driver": "GTiff",
+            "width": image.shape[1],
+            "height": image.shape[0],
+            "nodata": None
+        }
+        with rasterio.open(outfilename, 'w', **kwargs) as out:
+            out.write(image, indexes=1)
+
+        return outfilename
+
+    return inner
+
+
 @pytest.fixture(scope='function')
 def gdalenv(request):
-    import rasterio.env
-
     def fin():
         if rasterio.env.local._env:
             rasterio.env.delenv()
@@ -650,3 +671,17 @@ requires_gdal_lt_35 = pytest.mark.skipif(
     gdal_version.at_least('3.5'),
     reason="Requires GDAL before 3.5",
 )
+
+
+def assert_bounding_box_equal(expected, actual, tolerance=1e-4):
+    if isinstance(expected, tuple):
+        expected = BoundingBox(*expected)
+    if isinstance(actual, tuple):
+        actual = BoundingBox(*actual)
+
+    left = abs(expected.left - actual.left)
+    bottom = abs(expected.bottom - actual.bottom)
+    right = abs(expected.right - actual.right)
+    top = abs(expected.top - actual.top)
+
+    assert all(diff < tolerance for diff in [left, bottom, right, top]), f"{expected} differs from {actual}"
