@@ -19,7 +19,7 @@ def tempfile():
 
 def image(height, width, dtype):
     """An array with sequential elements"""
-    return np.array(range(height * width), dtype=dtype).reshape(height, width)
+    return np.array(range(height * width)).astype(dtype).reshape(height, width)
 
 
 dtypes = ['uint8', 'uint16', 'int16', 'uint32', 'int32', 'float32', 'float64']
