@@ -12,10 +12,9 @@ from .conftest import requires_gdal35, gdal_version
 import rasterio
 from rasterio.drivers import blacklist
 from rasterio.enums import MaskFlags, Resampling
-from rasterio.env import Env
+from rasterio.env import Env, GDALVersion
 from rasterio.errors import RasterioIOError
 
-
 def test_validate_dtype_None(tmpdir):
     """Raise TypeError if there is no dtype"""
     name = str(tmpdir.join("lol.tif"))
@@ -118,7 +117,10 @@ def test_write_sbyte(tmpdir):
 
     info = subprocess.check_output(["gdalinfo", "-stats", name]).decode('utf-8')
     assert "Minimum=-33.000, Maximum=-33.000, Mean=-33.000, StdDev=0.000" in info
-    assert 'SIGNEDBYTE' in info
+    if GDALVersion.runtime() < GDALVersion(3, 7):
+        assert 'SIGNEDBYTE' in info
+    else:
+        assert 'Int8' in info
 
 
 @pytest.mark.gdalbin
